@@ -47,7 +47,7 @@ our %EXPORT_TAGS = (
     type => [grep m/type_/, @EXPORT_OK],
 );
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 sub new {
     shift and goto &deduce_deep;
@@ -328,7 +328,7 @@ Data::Object - Data Type Objects for Perl 5
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -342,9 +342,7 @@ version 0.19
 =head1 DESCRIPTION
 
 Data::Object provides functions for promoting Perl 5 native data types to
-objects which provide common methods for operating on the data. B<Note: This is
-an early release available for testing and feedback and as such is subject to
-change.>
+objects which provide common methods for operating on the data.
 
 =head1 EXPORTS
 
